@@ -1,5 +1,5 @@
 import os
-from pyprotobuf.parser import ProtoParser
+from pyprotobuf.parser import ProtoParser, ParseError
 from pyprotobuf.codegenerator import Frame
 from pyprotobuf.nameresolver import NameResolver
 from pyprotobuf.commentresolver import CommentResolver
@@ -27,7 +27,12 @@ class Compiler(object):
             return self.compile_string(filename, f.read())
 
     def compile_string(self, filename, string):
-        rootnode = self.precompile_string(filename, string)
+        try:
+            rootnode = self.precompile_string(filename, string)
+        except ParseError as e:
+            print str(e)
+            raise
+
         generator = self.generator_class()
         # only compile the last package for now
         return generator.generate_file(rootnode.children[-1].children[0])
