@@ -29,6 +29,11 @@ class ProtorpcTest(unittest.TestCase):
         self.maxDiff = 1500
         self.check_expected_output('enum_global.proto')
 
+    def test_defaults(self):
+        """ Test enum globals are sorted.
+        """
+        self.maxDiff = 1500
+        self.check_expected_output('defaults.proto')
 
 if __name__ == '__main__':
     unittest.main()
