@@ -93,8 +93,8 @@ scanner = re.Scanner([
 
 
 class ParseError(Exception):
-    def __repr__(self):
-        return 'Parse Error: %s [%s:%s]' % (self.msg, self.line, self.col)
+    def __str__(self):
+        return 'Parse Error: %s [%s:%s]' % (self.message, self.line, self.col)
 
 
 class ProtoParser(object):
@@ -206,33 +206,33 @@ class ProtoParser(object):
 
     def read_string_or_id(self, t):
         tok = t.next_token()
-        assert tok.type == TOKEN_STRING or tok.type == TOKEN_NAME, "Expected ident/string literal. Got %s" % tok
+        self.assert_token_expression(tok.type == TOKEN_STRING or tok.type == TOKEN_NAME, tok, "Expected ident/string literal. Got %s" % tok)
         if tok.type == TOKEN_STRING:
             tok.value = tok.value.strip("'" + '"')
         return tok
 
     def read_string_or_id_or_num(self, t):
         tok = t.next_token()
-        assert tok.type == TOKEN_STRING or tok.type == TOKEN_NAME or tok.type == TOKEN_NUMBER, "Expected ident/string literal/num. Got %s" % tok
+        self.assert_token_expression(tok.type == TOKEN_STRING or tok.type == TOKEN_NAME or tok.type == TOKEN_NUMBER, tok, "Expected ident/string literal/num. Got %s" % tok)
         if tok.type == TOKEN_STRING:
             tok.value = tok.value.strip("'" + '"')
         return tok
 
     def read_string(self, t):
         tok = t.next_token()
-        assert tok.type == TOKEN_STRING, "Expected string literal. Got %s" % tok
+        self.assert_token_expression(tok.type == TOKEN_STRING, tok, "Expected string literal. Got %s" % tok)
         if tok.type == TOKEN_STRING:
             tok.value = tok.value.strip("'" + '"')
         return tok
 
     def read_equals(self, t):
         tok = t.next_token()
-        assert tok.value == '=', "Expected =, Got %s" % tok
+        self.assert_token_expression(tok.value == '=', tok, "Expected =, Got %s" % tok)
         return tok
 
     def read_number(self, t):
         tok = t.next_token()
-        assert (tok.type == TOKEN_STRING or tok.type == TOKEN_NUMBER), "Expect Number. Got: %s" % tok
+        self.assert_token_expression(tok.type == TOKEN_STRING or tok.type == TOKEN_NUMBER, tok, "Expect Number. Got: %s" % tok)
         return tok
 
     def read_name2(self, t):
@@ -241,6 +241,10 @@ class ProtoParser(object):
         self.assert_token(name, TOKEN_NAME, message="Expected identifier. Got: %s" % name)
         return name
 
+    def assert_token_expression(self, expr, token, error_message):
+        if not expr:
+            self.raise_token_error(token, error_message)
+
     def read_semi(self, t):
         semi = t.next_token(False)
         self.assert_token(semi, TOKEN_OP, value=";", message='Expected ; Got' + str(semi.value))
@@ -254,8 +258,18 @@ class ProtoParser(object):
         next = t.next_token()
         self.assert_token(next, match_type, value=expected, message='Expected %s. Got %s' % (expected, next))
 
+    def format_token_position(self, token):
+        return "[%s:%s]" % (token.start[0], token.start[1])
+
+    def raise_token_error(self, token, message):
+        pe = ParseError(message)
+        pe.line = token.start[0]
+        pe.col = token.start[1]
+        raise pe
+
+
     def assert_token(self, token, type, value=None, message=None):
-        message = "Expected %s @ [%s:%s]" % (value, token.start[0], token.start[1])
+        message = "Expected %s %s" % (value, self.format_token_position(token))
 
         pe = ParseError(message)
         pe.line = token.start[0]
@@ -475,7 +489,7 @@ class ProtoParser(object):
             elif token.value == 'optional':
                 extend.add_child(self.parse_optional_stmt(t))
             else:
-                raise Exception("Unexpected token: %s" % token)
+                self.raise_token_error(token, "Unexpected token: %s" % token)
         return extend
 
     def parse_import_stmt(self, t):
@@ -485,7 +499,7 @@ class ProtoParser(object):
         
         import_path = self.read_string_or_id(t)
         semi = t.next_token()
-        assert semi.type == TOKEN_OP and semi.value == ';', 'Expected semicolon'
+        self.assert_token_expression(semi.type == TOKEN_OP and semi.value == ';', semi,  'Expected semicolon')
         node = ImportNode()
         node.value = import_path.value
         logger.debug('Read import node %s', node)
@@ -518,9 +532,9 @@ class ProtoParser(object):
         fdn.type = t.read_id()
         fdn.name = t.next_token().value
         equals = t.next_token()
-        assert equals.type == TOKEN_OP and equals.value == '=', "Missing equals. Got %s" % str(equals)
+        self.assert_token_expression(equals.type == TOKEN_OP and equals.value == '=', equals, "Missing equals. Got %s" % str(equals))
         number = t.next_token()
-        assert number.type == TOKEN_NUMBER, "Tag should be a number"
+        self.assert_token_expression(number.type == TOKEN_NUMBER, number, "Tag should be a number")
         if number.value.startswith('0x'):
             fdn.number = int(number.value, 16)
         else:
@@ -529,7 +543,7 @@ class ProtoParser(object):
         # group nodes have a braces after with a list of fielddesc inside
         if fdn.type == "group":
             next = t.readahead()
-            assert next.value == '{'
+            self.assert_token_expression(next.value == '{', next, "Expected {")
             fdn.children = self.parse_group_body(t)
             logger.debug('Parse group body %s', fdn.children)
             #next = t.readahead()
@@ -583,8 +597,12 @@ class ProtoParser(object):
             self.assert_read(t, TOKEN_RPAR, ')')
         else:
             name.append(next.value)
+            logger.debug('Read k/v: %s %s', ''.join(name), next.value)
+
+        #next = t.next_token()
+        logger.debug('NEXT IS %s', next)
         self.read_equals(t)
-        value = self.read_string_or_id_or_num(t)
+        value = self.read_dotted(t)
 
         return ''.join(name), value.value
 
