@@ -10,4 +10,5 @@ class Visitor(object):
             self.visit(child)
             
     def visit_unknown(self, child):
-        print 'unknown', child
+        #print 'unknown', child
+        pass
